@@ -109,8 +109,8 @@ IntersectionType BoxIntersects(StaticPropRange needle, StaticPropRange haystack,
 void SplitTreeSamples(TreeSamples &tree_samples, size_t begin, size_t pos,
                       size_t end, size_t prop) {
   auto cmp = [&](size_t a, size_t b) {
-    return int32_t(tree_samples.Property(prop, a)) -
-           int32_t(tree_samples.Property(prop, b));
+    return static_cast<int32_t>(tree_samples.Property(prop, a)) -
+           static_cast<int32_t>(tree_samples.Property(prop, b));
   };
   Rng rng(0);
   while (end > begin + 1) {
@@ -243,7 +243,8 @@ void FindBestSplit(TreeSamples &tree_samples, float threshold,
     // properties. We do this even if the current node is not a leaf, to
     // minimize the number of nodes in the resulting tree.
     for (size_t i = 0; i < mul_info.size(); i++) {
-      uint32_t axis, val;
+      uint32_t axis;
+      uint32_t val;
       IntersectionType t =
           BoxIntersects(static_prop_range, mul_info[i].range, axis, val);
       if (t == IntersectionType::kNone) continue;
@@ -696,7 +697,11 @@ void TreeSamples::Swap(size_t a, size_t b) {
 }
 
 void TreeSamples::ThreeShuffle(size_t a, size_t b, size_t c) {
-  if (b == c) return Swap(a, b);
+  if (b == c) {
+    Swap(a, b);
+    return;
+  }
+
   for (auto &r : residuals) {
     auto tmp = r[a];
     r[a] = r[c];
